@@ -86,8 +86,7 @@ class Util(object):
     def adb(self, arg, timeout=30, encoding='utf-8'):
         adb = 'adb'
         if self.is_wsl:  # 适配 wsl2 中使用 win10 中的adb情况
-            arg = 'whereis adb'  # 获取 adb 的 path
-            out = Util.cmd(arg)
+            out = Util.cmd('whereis adb')
             if 'adb:' in out:
                 out = out.replace('adb:', '').strip().split(' /')[0]  # 使用第一个 path
                 if 'adb' in out:
